"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const _ = __importStar(require("lodash"));
const metadataInfo_1 = require("../metadataInfo");
const baseMetadataRetriever_1 = __importDefault(require("./baseMetadataRetriever"));
const metadataFiles_1 = __importDefault(require("../metadataFiles"));
const QUERY = "Select Id, Name, NameSpacePrefix From ApexClass ";
class ApexClassRetriever extends baseMetadataRetriever_1.default {
    constructor(org) {
        super(org, true);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!ApexClassRetriever.instance) {
            ApexClassRetriever.instance = new ApexClassRetriever(org);
        }
        return ApexClassRetriever.instance;
    }
    async getObjects() {
        if ((this.data === undefined || this.data.length == 0) &&
            !this.dataLoaded) {
            super.setQuery(QUERY);
            let classes = await super.getObjects();
            for (let i = 0; i < classes.length; i++) {
                let cls = classes[i];
                if (!_.isNil(cls.NamespacePrefix)) {
                    cls.FullName = `${cls.NamespacePrefix}__${cls.Name}`;
                }
                else {
                    cls.FullName = cls.Name;
                }
            }
            this.data = classes;
            this.dataLoaded = true;
        }
        return this.data;
    }
    async getClasses() {
        return await this.getObjects();
    }
    async classExists(cls) {
        let found = false;
        //Look first in project files
        if (!_.isNil(metadataInfo_1.METADATA_INFO.ApexClass.components)) {
            found = metadataInfo_1.METADATA_INFO.ApexClass.components.includes(cls);
        }
        if (!found && !metadataFiles_1.default.sourceOnly) {
            //not found, check on the org
            let classes = await this.getClasses();
            let foundCls = classes.find(aCls => {
                return aCls.FullName === cls;
            });
            found = !_.isNil(foundCls);
        }
        return found;
    }
}
exports.default = ApexClassRetriever;
//# sourceMappingURL=apexClassRetriever.js.map